==> owncloud-4.5.7.tgz: owncloud/apps/contacts/l10n/mk.php <==
<?php $TRANSLATIONS = array(
"Error (de)activating addressbook." => "Грешка (де)активирање на адресарот.",
"id is not set." => "ид не е поставено.",
"Cannot update addressbook with an empty name." => "Неможе да се ажурира адресар со празно име.",
"No ID provided" => "Нема доставено ИД",
"Error setting checksum." => "Грешка во поставување сума за проверка.",
"No categories selected for deletion." => "Нема избрано категории за бришење.",
"No address books found." => "Не се најдени адресари.",
"No contacts found." => "Не се најдени контакти.",
"element name is not set." => "име за елементот не е поставена.",
"Cannot add empty property." => "Неможе да се додаде празна вредност.",
"At least one of the address fields has to be filled out." => "Барем една од полињата за адреса треба да биде пополнето.",
"Trying to add duplicate property: " => "Се обидовте да внесете дупликат вредност:",
"Information about vCard is incorrect. Please reload the page." => "Информацијата за vCard не е точна. Ве молам превчитајте ја страницава.",
"Missing ID" => "Недостасува ИД",
"Error parsing VCard for ID: \"" => "Грешка при парсирање VCard за ИД: \"",
"checksum is not set." => "сумата за проверка не е поставена.",
"Information about vCard is incorrect. Please reload the page: " => "Информацијата за vCard не е точна. Ве молам превчитајте ја страницава:",
"Something went FUBAR. " => "Нешто се расипа.",
"No contact ID was submitted." => "Не беше доставено ИД за контакт.",
"Error reading contact photo." => "Грешка во читање на контакт фотографија.",
"Error saving temporary file." => "Грешка во снимање на привремена датотека.",
"The loading photo is not valid." => "Фотографијата која се вчитува е невалидна.",
"Contact ID is missing." => "ИД за контакт недостасува.",
"No photo path was submitted." => "Не беше поднесена патека за фотографија.",
"File doesn't exist:" => "Не постои датотеката:",
"Error loading image." => "Грешка во вчитување на слика.",
"Error getting contact object." => "Грешка при преземањето на контакт објектот,",
"Error getting PHOTO property." => "Грешка при утврдувањето на карактеристиките на фотографијата.",
"Error saving contact." => "Грешка при снимање на контактите.",
"Error resizing image" => "Грешка при скалирање на фотографијата",
"Error cropping image" => "Грешка при сечење на фотографијата",
"Error creating temporary image" => "Грешка при креирањето на привремената фотографија",
"Error finding image: " => "Грешка при наоѓањето на фотографијата:",
"Error uploading contacts to storage." => "Грешка во снимање на контактите на диск.",
"There is no error, the file uploaded with success" => "Датотеката беше успешно подигната.",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "Големината на датотеката ја надминува upload_max_filesize директивата во php.ini",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "Големината на датотеката ја надминува MAX_FILE_SIZE директивата која беше специфицирана во HTML формата",
"The uploaded file was only partially uploaded" => "Датотеката беше само делумно подигната.",
"No file was uploaded" => "Не беше подигната датотека.",
"Missing a temporary folder" => "Недостасува привремена папка",
"Couldn't save temporary image: " => "Не можеше да се сними привремената фотографија:",
"Couldn't load temporary image: " => "Не можеше да се вчита привремената фотографија:",
"No file was uploaded. Unknown error" => "Ниту еден фајл не се вчита. Непозната грешка",
"Contacts" => "Контакти",
"Sorry, this functionality has not been implemented yet" => "Жалам, оваа функционалност уште не е имплементирана",
"Not implemented" => "Не е имплементирано",
"Couldn't get a valid address." => "Не можев да добијам исправна адреса.",
"Error" => "Грешка",
"Format custom, Short name, Full name, Reverse or Reverse with comma" => "Прилагоден формат, кратко име, цело име, обратно или обратно со запирка",
"Select type" => "Одбери тип",
"This property has to be non-empty." => "Својството не смее да биде празно.",
"Couldn't serialize elements." => "Не може да се серијализираат елементите.",
"'deleteProperty' called without type argument. Please report at bugs.owncloud.org" => "'deleteProperty' повикан без тип на аргументот. Пријавете грешка/проблем на bugs.owncloud.org",
"Edit name" => "Уреди го името",
"No files selected for upload." => "Ниту еден фајл не е избран за вчитување.",
"The file you are trying to upload exceed the maximum size for file uploads on this server." => "Датотеката која се обидувате да ја префрлите ја надминува максималната големина дефинирана за пренос на овој сервер.",
"Result: " => "Резултат: ",
" imported, " => "увезено,",
" failed." => "неуспешно.",
"Download" => "Преземи",
"Edit" => "Уреди",
"Delete" => "Избриши",
"Cancel" => "Откажи",
"This is not your addressbook." => "Ова не е во Вашиот адресар.",
"Contact could not be found." => "Контактот неможе да биде најден.",
"Work" => "Работа",
"Home" => "Дома",
"Mobile" => "Мобилен",
"Text" => "Текст",
"Voice" => "Глас",
"Message" => "Порака",
"Fax" => "Факс",
"Video" => "Видео",
"Pager" => "Пејџер",
"Internet" => "Интернет",
"Birthday" => "Роденден",
"{name}'s Birthday" => "Роденден на {name}",
"Contact" => "Контакт",
"Add Contact" => "Додади контакт",
"Import" => "Внеси",
"Close" => "Затвои",
"Drop photo to upload" => "Довлечкај фотографија за да се подигне",
"Delete current photo" => "Избриши моментална фотографија",
"Edit current photo" => "Уреди моментална фотографија",
"Upload new photo" => "Подигни нова фотографија",
"Select photo from ownCloud" => "Изберете фотографија од ownCloud",
"Edit name details" => "Уреди детали за име",
"Organization" => "Организација",
"Nickname" => "Прекар",
"Enter nickname" => "Внеси прекар",
"dd-mm-yyyy" => "dd-mm-yyyy",
"Groups" => "Групи",
"Separate groups with commas" => "Одвоете ги групите со запирка",
"Edit groups" => "Уреди групи",
"Preferred" => "Претпочитано",
"Please specify a valid email address." => "Ве молам внесете правилна адреса за е-пошта.",
"Enter email address" => "Внесете е-пошта",
"Mail to address" => "Прати порака до адреса",
"Delete email address" => "Избриши адреса за е-пошта",
"Enter phone number" => "Внесете телефонски број",
"Delete phone number" => "Избриши телефонски број",
"View on map" => "Погледајте на мапа",
"Edit address details" => "Уреди детали за адреса",
"Add notes here." => "Внесете забелешки тука.",
"Add field" => "Додади поле",
"Phone" => "Телефон",
"Email" => "Е-пошта",
"Address" => "Адреса",
"Note" => "Забелешка",
"Download contact" => "Преземи го контактот",
"Delete contact" => "Избриши го контактот",
"The temporary image has been removed from cache." => "Привремената слика е отстранета од кешот.",
"Edit address" => "Уреди адреса",
"Type" => "Тип",
"PO Box" => "Поштенски фах",
"Extended" => "Дополнително",
"City" => "Град",
"Region" => "Регион",
"Zipcode" => "Поштенски код",
"Country" => "Држава",
"Addressbook" => "Адресар",
"Hon. prefixes" => "Префикси за титула",
"Miss" => "Г-ца",
"Ms" => "Г-ѓа",
"Mr" => "Г-дин",
"Sir" => "Сер",
"Mrs" => "Г-ѓа",
"Dr" => "Др",
"Given name" => "Лично име",
"Additional names" => "Дополнителни имиња",
"Family name" => "Презиме",
"Hon. suffixes" => "Суфикси за титула",
"J.D." => "J.D.",
"M.D." => "Д.М.",
"D.O." => "D.O.",
"D.C." => "D.C.",
"Ph.D." => "Д-р",
"Esq." => "Esq.",
"Jr." => "Помлад.",
"Sn." => "Постар.",
"Import a contacts file" => "Внеси датотека со контакти",
"Please choose the addressbook" => "Ве молам изберете адресар",
"create a new addressbook" => "креирај нов адресар",
"Name of new addressbook" => "Име на новиот адресар",
"Importing contacts" => "Внесување контакти",
"Add contact" => "Додади контакт",
"CardDAV syncing addresses" => "Адреса за синхронизација со CardDAV",
"more info" => "повеќе информации",
"Primary address (Kontact et al)" => "Примарна адреса",
"iOS/OS X" => "iOS/OS X",
"Addressbooks" => "Адресари",
"New Address Book" => "Нов адресар",
"Save" => "Сними"
);

==> owncloud-5.0.9.tgz: owncloud/apps/contacts/l10n/mk.php <==
<?php $TRANSLATIONS = array(
"Error (de)activating addressbook." => "Грешка (де)активирање на адресарот.",
"id is not set." => "ид не е поставено.",
"Cannot update addressbook with an empty name." => "Неможе да се ажурира адресар со празно име.",
"No ID provided" => "Нема доставено ИД",
"Error setting checksum." => "Грешка во поставување сума за проверка.",
"No categories selected for deletion." => "Нема избрано категории за бришење.",
"No address books found." => "Не се најдени адресари.",
"No contacts found." => "Не се најдени контакти.",
"element name is not set." => "име за елементот не е поставена.",
"checksum is not set." => "сумата за проверка не е поставена.",
"Information about vCard is incorrect. Please reload the page." => "Информацијата за vCard не е точна. Ве молам превчитајте ја страницава.",
"Information about vCard is incorrect. Please reload the page: " => "Информацијата за vCard не е точна. Ве молам превчитајте ја страницава:",
"Something went FUBAR. " => "Нешто се расипа.",
"No contact ID was submitted." => "Не беше доставено ИД за контакт.",
"Error reading contact photo." => "Грешка во читање на контакт фотографија.",
"Error saving temporary file." => "Грешка во снимање на привремена датотека.",
"The loading photo is not valid." => "Фотографијата која се вчитува е невалидна.",
"Contact ID is missing." => "ИД за контакт недостасува.",
"No photo path was submitted." => "Не беше поднесена патека за фотографија.",
"File doesn't exist:" => "Не постои датотеката:",
"Error loading image." => "Грешка во вчитување на слика.",
"Error getting contact object." => "Грешка при преземањето на контакт објектот,",
"Error getting PHOTO property." => "Грешка при утврдувањето на карактеристиките на фотографијата.",
"Error saving contact." => "Грешка при снимање на контактите.",
"Error resizing image" => "Грешка при скалирање на фотографијата",
"Error cropping image" => "Грешка при сечење на фотографијата",
"Error creating temporary image" => "Грешка при креирањето на привремената фотографија",
"Error finding image: " => "Грешка при наоѓањето на фотографијата:",
"Error uploading contacts to storage." => "Грешка во снимање на контактите на диск.",
"There is no error, the file uploaded with success" => "Датотеката беше успешно подигната.",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "Големината на датотеката ја надминува upload_max_filesize директивата во php.ini",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "Големината на датотеката ја надминува MAX_FILE_SIZE директивата која беше специфицирана во HTML формата",
"The uploaded file was only partially uploaded" => "Датотеката беше само делумно подигната.",
"No file was uploaded" => "Не беше подигната датотека.",
"Missing a temporary folder" => "Недостасува привремена папка",
"Couldn't save temporary image: " => "Не можеше да се сними привремената фотографија:",
"Couldn't load temporary image: " => "Не можеше да се вчита привремената фотографија:",
"No file was uploaded. Unknown error" => "Ниту еден фајл не се вчита. Непозната грешка",
"Contacts" => "Контакти",
"Select photo" => "Одбери фотографија",
"Error" => "Грешка",
"Unable to upload your file as it is a directory or has 0 bytes" => "Не може да се преземе вашата датотека бидејќи фолдерот во кој се наоѓа фајлот има големина од 0 бајти",
"Upload Error" => "Грешка при преземање",
"The file you are trying to upload exceed the maximum size for file uploads on this server." => "Датотеката која се обидувате да ја префрлите ја надминува максималната големина дефинирана за пренос на овој сервер.",
"Upload too large" => "Фајлот кој се вчитува е преголем",
"Pending" => "Чека",
"No files selected for upload." => "Ниту еден фајл не е избран за вчитување.",
"Result: " => "Резултат: ",
" imported, " => "увезено,",
" failed." => "неуспешно.",
"Displayname cannot be empty." => "Прикажаното име не може да биде празно.",
"Download" => "Преземи",
"Edit" => "Уреди",
"Delete" => "Избриши",
"Cancel" => "Откажи",
"Work" => "Работа",
"Home" => "Дома",
"Other" => "Останато",
"Mobile" => "Мобилен",
"Text" => "Текст",
"Voice" => "Глас",
"Message" => "Порака",
"Fax" => "Факс",
"Video" => "Видео",
"Pager" => "Пејџер",
"Internet" => "Интернет",
"{name}'s Birthday" => "Роденден на {name}",
"Contact" => "Контакт",
"Settings" => "Параметри",
"Import" => "Внеси",
"OK" => "Во ред",
"Groups" => "Групи",
"Close" => "Затвои",
"Add contact" => "Додади контакт",
"Delete current photo" => "Избриши моментална фотографија",
"Edit current photo" => "Уреди моментална фотографија",
"Upload new photo" => "Подигни нова фотографија",
"Select photo from ownCloud" => "Изберете фотографија од ownCloud",
"Additional names" => "Дополнителни имиња",
"Nickname" => "Прекар",
"Enter nickname" => "Внеси прекар",
"Title" => "Наслов",
"Organization" => "Организација",
"Birthday" => "Роденден",
"Add" => "Додади",
"Phone" => "Телефон",
"Email" => "Е-пошта",
"Address" => "Адреса",
"Note" => "Забелешка",
"Delete contact" => "Избриши го контактот",
"Preferred" => "Претпочитано",
"Please specify a valid email address." => "Ве молам внесете правилна адреса за е-пошта.",
"Mail to address" => "Прати порака до адреса",
"Delete email address" => "Избриши адреса за е-пошта",
"Enter phone number" => "Внесете телефонски број",
"Delete phone number" => "Избриши телефонски број",
"View on map" => "Погледајте на мапа",
"City" => "Град",
"Country" => "Држава",
"Share" => "Сподели",
"Export" => "Извези",
"The temporary image has been removed from cache." => "Привремената слика е отстранета од кешот.",
"CardDAV syncing addresses" => "Адреса за синхронизација со CardDAV",
"more info" => "повеќе информации",
"Primary address (Kontact et al)" => "Примарна адреса",
"iOS/OS X" => "iOS/OS X",
"Addressbooks" => "Адресари",
"New Address Book" => "Нов адресар",
"Name" => "Име",
"Save" => "Сними"
);
